![FakeSnake_Logo](assets/banner.png)

[Go to table of contents](#table-of-contents)

## Usages

![fakesnake_demo_gif](assets/fakesnake_demo.gif)

```bash
fakes --help

#    Usage: fakes [OPTIONS] COMMAND [ARGS]...
#
#    Options:
#      --help  Show this message and exit.
#
#    Commands:
#      address
#      email
#      name
#      number
#      password
```

## Install

```bash
pip install fakesnake
```

## FAQ

1.  Q: Where to report problems?

    A: Open up an [issue](https://github.com/Vin-Cento/fakesnake/issues/new)

## Table of Contents

1. [Introduction](#introduction)
2. [Usages](#usages)
3. [Install](#install)
4. [FAQ](#faq)

## TODO

- [x] set length of password when generating
- [x] upload to database
